const
  commander = require('commander'),
  _ = require('lodash'),
  webpackConfig = require('./webpack.config.js')

module.exports = function(karma) {
  var conf = {
    frameworks: [ 'mocha', 'chai', 'server-side' ],

    files: [
        'test/karma_index.js',
        {
            // watch all files in src
            pattern: 'src/**',
            included: false,
            served: false,
            nocache: true
        }
    ],

    preprocessors: {
      'test/karma_index.js': [ 'webpack', 'sourcemap' ]
    },

    webpack: webpackConfig,
    webpackMiddleware: { stats: { colors: karma.colors } },

    reporters: [ 'mocha', 'coverage' ],
    mochaReporter: { showDiff: true },
    coverageReporter: {
      dir: './coverage',
      reporters: [
        { type: 'lcov', subdir: '.' },
        { type: 'json', subdir: '.' },
        { type: 'text-summary' }
      ]
    },
    // browserDisconnectTimeout: 30000, /* useful for debugging */
    // logLevel: karma.LOG_DEBUG, /* useful for debugging */
    client: {
        mocha: { timeout: 5000 }
    },
    customLaunchers: {
      ChromiumDocker: { base: 'ChromiumHeadless', flags: ['--no-sandbox'] }
    },

    // Valid values: Chrome Firefox jsdom
    // can also be set on commandline with --browsers ...
    browsers: []
  };

  var opts = commander
  .option('-d, --debug', 'enable debug')
  .option('-g, --grep <pattern>', 'test cases filter regex')
  .parse(process.argv);

  /* used by babel */
  if (!opts.debug) {
    process.env.NODE_ENV = "test";
  }

  if (opts.grep) {
    _.set(conf, 'client.mocha.grep', opts.grep);
  }
  karma.set(conf);
}
