//@flow

import { waitFor } from './test_utils';

import { afterEach, describe, it } from 'mocha';
import { expect } from 'chai';
import { mount } from '@vue/test-utils';

import { BaseCard as Card } from '../src';

describe('BaseCard', function() {
  var wrapper/*: Vue$Wrapper */;
  const stubs = { 'transition-group': false, 'transition': false };

  afterEach(function() {
    if (wrapper) {
      wrapper.destroy();
      /* $FlowIgnore */
      wrapper = null;
    }
  });

  it('can mount a Card', function() {
    wrapper = mount(Card, { propsData: { title: 'test title' }, stubs });

    return waitFor(wrapper, () => wrapper.find('.card-header').exists())
    .then(() => {
      var header = wrapper.find('.card-header');
      expect(header.text()).to.equal('test title');
      wrapper.setProps({ title: '' });
    })
    .then(() => waitFor(wrapper, () => !wrapper.find('.card-header').exists()));
  });

  it('can toggle footer', function() {
    wrapper = mount({
      components: { Card },
      template: `<Card>
          <template v-if="footer" v-slot:footer>footer content</template>
        </Card>`,
      data: () => ({ footer: true })
    }, { stubs });

    return waitFor(wrapper, () => wrapper.find('.card-footer').exists())
    .then(() => {
      expect(wrapper.find('.card-footer').text()).to.equal('footer content');
      wrapper.setData({ footer: false });
    })
    .then(() => waitFor(wrapper, () => !wrapper.find('.card-footer').exists()))
    .then(() => wrapper.setData({ footer: true }))
    .then(() => waitFor(wrapper, () => wrapper.find('.card-footer').exists()));
  });

  it('can display content', function() {
    wrapper = mount({
      components: { Card },
      template: `<Card>
          <li v-if="body" key="0">some content</li>
        </Card>`,
      data: () => ({ body: true })
    }, { stubs });

    return waitFor(wrapper, () => wrapper.find('ul > li').exists())
    .then(() => {
      expect(wrapper.find('ul > li').text()).to.equal('some content');
      wrapper.vm.body = false;
    })
    .then(() => waitFor(wrapper, () => !wrapper.find('ul > li').exists()))
    .then(() => { wrapper.vm.body = true; })
    .then(() => waitFor(wrapper, () => wrapper.find('ul > li').exists()));
  });
});
