//@flow

import { waitFor } from './test_utils';

import { afterEach, describe, it } from 'mocha';
import { expect } from 'chai';
import { mount } from '@vue/test-utils';

import { BaseCollapsible as Collapsible } from '../src';

describe('BaseCollapsible', function() {
  var wrapper/*: Vue$Wrapper */;
  const stubs = { 'transition-group': false, 'transition': false };

  afterEach(function() {
    if (wrapper) {
      wrapper.destroy();
      /* $FlowIgnore */
      wrapper = null;
    }
  });

  it('can mount a Collapsible', function() {
    wrapper = mount(Collapsible, { propsData: { title: 'test title' }, stubs });

    return waitFor(wrapper, () => wrapper.find('h5').exists())
    .then(() => {
      var header = wrapper.find('h5');
      expect(header.text()).to.equal('test title');
      expect(wrapper.vm.isExpanded).to.be.false();
    });
  });

  it('can toggle content using props', function() {
    wrapper = mount(Collapsible, {
      propsData: { expand: true },
      slots: {
        default: 'body content',
        header: 'header title'
      }, stubs });

    return waitFor(wrapper, () => wrapper.find({ ref: 'content' }).isVisible())
    .then(() => {
      expect(wrapper.find({ ref: 'header' }).text()).to.equal('header title');
      var content = wrapper.find({ ref: 'content' });
      expect(content.text()).to.equal('body content');

      wrapper.setProps({ expand: false });
      return waitFor(wrapper, () => !content.isVisible())
      .then(() => wrapper.setProps({ expand: true }))
      .then(() => waitFor(wrapper, () => content.isVisible()));
    });
  });

  it('can toggle content by clicking', function() {
    wrapper = mount(Collapsible, {
      slots: {
        default: 'body content',
        header: 'header title'
      }, stubs });

    return waitFor(wrapper, () => !wrapper.find({ ref: 'content' }).isVisible())
    .then(() => {
      var content = wrapper.find({ ref: 'content' });

      wrapper.find('i').trigger('click');
      return waitFor(wrapper, () => content.isVisible())
      .then(() => wrapper.find('i').trigger('click'))
      .then(() => waitFor(wrapper, () => !content.isVisible()));
    });
  });
});
