//@flow

import { afterEach, describe, it } from 'mocha';
import { expect } from 'chai';
import { mount } from '@vue/test-utils';

import { BaseParamInput as ParamInput } from '../src';

describe('ParamInput', function() {
  var wrapper/*: Vue$Wrapper */;

  afterEach(function() {
    if (wrapper) {
      wrapper.destroy();
      /* $FlowIgnore */
      wrapper = null;
    }
  });

  it('can mount a ParamInput', function() {
    wrapper = mount(ParamInput, {
      propsData: { title: 'Test Param', value: 42 }
    });

    expect(wrapper.find('.card-header').text()).to.equal('Test Param');

    expect(wrapper.vm.editValue).to.equal(42);
    wrapper.setProps({ inEdit: true });

    wrapper.find('input').setValue('44');
    expect(wrapper.vm.editValue).to.equal('44');

    wrapper.setProps({ inEdit: false });
    expect(wrapper.find('input'))
    .to.have.nested.property('element.value', '42');
  });

  it('can mount a readonly ParamInput', function() {
    wrapper = mount(ParamInput, {
      propsData: { title: 'Test Param', value: 42, readonly: true }
    });

    expect(wrapper.classes()).to.contain('b-param-primary');

    wrapper.setData({ editValue: 44 });
    wrapper.setProps({ inEdit: true });
    expect(wrapper.find('input'))
    .to.have.nested.property('element.value', '42');

    expect(wrapper.classes())
    .to.contain('b-param-secondary');
  });

  it('updates unmodified editValues', function() {
    wrapper = mount(ParamInput, {
      propsData: { title: 'Test Param' }
    });

    expect(wrapper.vm.editValue).to.be.undefined();
    wrapper.setProps({ value: 42 });
    expect(wrapper.vm.editValue).to.equal('42');
    wrapper.setProps({ value: 43 });
    expect(wrapper.vm.editValue).to.equal('43');

    wrapper.setData({ editValue: '42' });
    wrapper.setProps({ value: 44 });
    expect(wrapper.vm.editValue).to.equal('42');
  });
});
