//@flow

import { afterEach, describe, it } from 'mocha';
import { expect } from 'chai';
import { mount } from '@vue/test-utils';

import { BaseParamList as ParamList } from '../src';

describe('ParamList', function() {
  var wrapper/*: Vue$Wrapper */;

  afterEach(function() {
    if (wrapper) {
      wrapper.destroy();
      /* $FlowIgnore */
      wrapper = null;
    }
  });

  it('can mount a dynamic ParamList', function() {
    wrapper = mount(ParamList, {
      propsData: {
        title: 'Test Param', value: 2,
        options: [ { value: 0, text: 'ZERO' }, { value: 2, text: 'SEC' } ]
      }
    });

    expect(wrapper.find('.card-header').text()).to.equal('Test Param');
    expect(wrapper.find('input'))
    .to.have.nested.property('element.value', 'SEC');

    expect(wrapper.vm.editValue).to.equal(2);
    expect(wrapper.vm.valueText).to.equal('SEC');
    expect(wrapper.vm.editValueText).to.equal('SEC');

    wrapper.setProps({ inEdit: true });

    wrapper.findAll('select > option').at(0).setSelected();
    expect(wrapper.vm.editValue).to.equal(0);

    wrapper.setProps({ inEdit: false });
    expect(wrapper.vm.editValue).to.equal(0);
    expect(wrapper.vm.value).to.equal(2);

    expect(wrapper.find('input'))
    .to.have.nested.property('element.value', 'SEC');
  });

  it('can mount a static ParamList', function() {
    wrapper = mount(ParamList, {
      propsData: { value: '2' },
      slots: {
        options: `
          <option value="0">ZERO</option>
          <option value="2">SEC</option>`,
        title: 'Another title'
      }
    });

    expect(wrapper.find('.card-header').text()).to.equal('Another title');
    expect(wrapper.vm.editValue).to.equal('2');
    expect(wrapper.vm.valueText).to.equal('SEC');
    expect(wrapper.vm.editValueText).to.equal('SEC');

    wrapper.setProps({ inEdit: true });

    wrapper.findAll('select > option').at(0).setSelected();
    expect(wrapper.vm.editValue).to.equal('0');

    wrapper.setProps({ inEdit: false });
    expect(wrapper.vm.editValue).to.equal('0');
    expect(wrapper.vm.value).to.equal('2');
    expect(wrapper.find('input'))
    .to.have.nested.property('element.value', 'SEC');
  });

  it('updates unmodified editValues', function() {
    wrapper = mount(ParamList, {
      propsData: {
        title: 'Test Param', value: 2,
        options: [
          { value: 0, text: 'ZERO' },
          { value: 1, text: 'FIRST' },
          { value: 2, text: 'SEC' }
        ]
      }
    });

    expect(wrapper.vm.editValue).to.equal(2);
    wrapper.setProps({ value: 0 });
    expect(wrapper.vm.editValue).to.equal(0);
    wrapper.setProps({ value: 2 });
    expect(wrapper.vm.editValue).to.equal(2);

    wrapper.setData({ editValue: 1 });
    wrapper.setProps({ value: 0 });
    expect(wrapper.vm.editValue).to.equal(1);
  });
});
