//@flow
import _ from 'lodash';
import q from 'q';

export function waitFor(vm /*: any */, cb /*: (vm: Vue$Component) => boolean */, timeout /*: ?number */) {
  if (_.has(vm, 'vm')) {
    vm = vm.vm; /* probably a wrapper */
  }
  var def = q.defer();
  var err = new Error('timeout'); /* create this early to have stacktrace */
  var timer = _.delay(def.reject.bind(def, err),
    _.defaultTo(timeout, 1000));

  function next() {
    vm.$nextTick(() => {
      if (def.promise.isFulfilled()) {
        return;
      }
      try {
        var ret = cb(vm); /* eslint-disable-line callback-return */
        if (ret) {
          clearTimeout(timer);
          def.resolve(ret);
        }
        else {
          _.delay(next, 200);
        }
      }
      catch (e) {
        clearTimeout(timer);
        def.reject(_.has(e, 'message') ? e : new Error(e));
      }
    });
  }

  _.delay(next, 200);
  return def.promise;
}
